@@ -462,8 +462,8 @@ class AWSpider:
         return d
         
     def _getTimeOffsetCallback( self, time_offset ):
-        logger.info( "Got time offset for sync." )
         self.time_offset = time_offset
+        logger.info( "Got time offset for sync: %s" % self.time_offset )
     
     def _getTimeOffsetErrback( self, error ):
         if self.time_offset is None:
@@ -761,7 +761,7 @@ class AWSpider:
         reactor.callLater( 1, reactor.stop )
     
     def coordinate( self ):
-        logger.debug( "Peers: %s" % self.peers )
+        #logger.debug( "Peers: %s" % self.peers )
         attributes = { "created":sdb_now(offset=self.time_offset) }
         attributes.update( self.network_information )
         self.sdb.putAttributes( self.aws_sdb_coordination_domain, self.uuid, attributes, replace=attributes.keys() )
@@ -770,7 +770,7 @@ class AWSpider:
     def checkPeers( self ):
         logger.debug( sdb_now( offset=self.time_offset) )
         sql = "SELECT public_ip, local_ip, port FROM %s WHERE created > '%s'" % ( self.aws_sdb_coordination_domain, sdb_now_add( self.peer_check_interval * -2, offset=self.time_offset) )
-        logger.debug( "Querying SimpleDB, \"%s\"" % sql )
+        #logger.debug( "Querying SimpleDB, \"%s\"" % sql )
         d = self.sdb.select( sql )
         d.addCallback( self._checkPeersCallback )
         d.addErrback( self._checkPeersErrback )
@@ -821,8 +821,8 @@ class AWSpider:
         self.peer_uuids = self.peers.keys()
         self.peer_uuids.sort()
         
-        print self.peers 
-        print self.peer_uuids
+#        print self.peers 
+        logger.debug( "Peers updated to: %s" % self.peer_uuids )
         
         # Go through the peers and reorganize the group.
         pass
