@@ -18,14 +18,16 @@ import gzip as gzip_package
 
 import dateutil.parser
 
-def sdb_now_plus( i ):
-    return str(int(time.time() + i)).zfill(11)
+def sdb_now(offset=0):
+    return str(int(offset + time.time())).zfill(11)
 
-def sdb_parse_time(s): # Parse a string into a SDB formatted timestamp
-    return str(int(time.mktime(dateutil.parser.parse( s ).timetuple()))).zfill(11)
+def sdb_now_add( i, offset=0 ):
+    return str(int(offset + time.time() + i) ).zfill(11)
+
+def sdb_parse_time(s, offset=0): # Parse a string into a SDB formatted timestamp
+    return str(int(offset + time.mktime(dateutil.parser.parse( s ).timetuple()))).zfill(11)
     
-def sdb_now():
-    return str(int(time.time())).zfill(11)
+
     
 def sdb_latitude( latitude ):
     adjusted = ( 90 + float( latitude ) ) * 100000
